%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program maps a point in AIGram to a point in STFT space
% Input:  t_AI, f_AI -- the coordinates of the point in AIGram space
%         Fs - the sampling frequency
% Output:  t_STFT, f_STFT -- the Look Up Table
%   Author:      Feipeng Li
%   E-mail:      fli2@uiuc.edu
%   Time-stamp:  2007-09-20
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [t_STFT, f_STFT] = ai2stft(t_AI, f_AI, nband_stft, nframe_stft, Fs)

global configs doc;

S = load([configs.syspath '/bin/event_gram/mat/standard.mat']);

nBands_AI = length(S.frequencies);

x_Apex = greenwood_inverse(179.46);
x_Base = greenwood_inverse(7520);

x_AI = linspace( x_Base, x_Apex, nBands_AI);
x_step = (x_Apex-x_Base)/nBands_AI;

f_AI = nBands_AI - f_AI; % reverse frequency

x = x_Base + f_AI*x_step;

freq = greenwood_inverse(x, 'dist');

f_STFT = freq/(Fs/2/nband_stft);

nband_AI = length(doc.aigram.freq_axis);
nframe_AI = length(doc.aigram.time_axis);

t_STFT = t_AI;      % no change in the time resolution




