%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program plot the instantaneous cc
% Input: cc -- the time variant communication compacity (cc) to be plotted
%        time_axis -- the time associated with the cc function 
%        wav_file -- name of the wav file (for labeling)
%        snr -- signal-to-noise ratio for a red line (for labeling)
%        t_star -- time for the event_gram (for labeling)
%        exp -- the id of the experiment (64 or 16)        
%   Author:      Feipeng Li revised from Marion's code
%   E-mail:      fli2@uiuc.edu
%   Time-stamp:  2007-06-05
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plot_cc(cc, wav_file, snr, t_star, exp)

fontsize = 8; 

name = fix_underscore(wav_file);
name = name([2:end-4]); 

data = cc.data;
time_axis = cc.time_axis;

start_time = min(time_axis);
end_time = max(time_axis);
t_star_col = round((t_star-start_time)/(end_time-start_time)*length(data));

[lmval,indd]=lmax(data); % find the peaks in the CC
x = find(lmval> 0.05); lmval = lmval(x); indd = indd(x);

plot(data, 'Linewidth', 2);
title(sprintf('Short-time AI above 2 kHz for %s at %d dB SNR', name, snr),'FontSize',fontsize+1)
hold on
% get rid of the peaks below threshold, so far let's say it's 0.05 bits
if t_star_col>0
    plot([t_star_col t_star_col], [0 data(t_star_col)],'Color', 'r', 'Linewidth', 2, 'Linestyle', '--');
end
p = find(indd==t_star_col); lmval(p) = 0; % to make sure that the thick red line for t_star does not overlap with the other lines.
for i=1:length(indd)
    plot([indd(i) indd(i)], [0 lmval(i)],'Color', 'r');
end
hold off

a = axis; 
a(3) = 0;
a(4) = ceil(max(data/100));
a(2) = length(data);
axis(a)

how_many_samples = length(data);
set(gca,'FontSize',fontsize)
set(gca,'XTick',40*[1:floor(how_many_samples/40)]);
set(gca,'XTickLabel',10*[1:floor(how_many_samples/40)]);

xlabel('Time [cs]');
ylabel('[bits/cs]','FontSize',fontsize)

if (t_star_col-3)>0  %JBA remove ^ from string
    text(t_star_col-3, data(t_star_col)+ 0.07 , 't*', 'FontSize',fontsize-2,'FontWeight', 'bold')
end
